"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cleanLog = void 0;
const to_checksum_address_1 = require("../../utils/to-checksum-address");
const hex_to_decimal_1 = require("./hex-to-decimal");
/**
 * Converts RPC log receipt response to more JS-friendly format
 *
 * @param log the log to clean
 * @param receiptLog if the log is part of a transaction receipt. Used to remove certain keys from log
 * @example
 */
function cleanLog(log, receiptLog) {
    const cleanedLog = {
        ...log,
    };
    Object.keys(log).forEach((key) => {
        switch (key) {
            case 'address':
                cleanedLog[key] = (0, to_checksum_address_1.toChecksumAddress)(log[key]);
                break;
            case 'blockNumber':
            case 'logIndex':
            case 'transactionIndex':
                cleanedLog[key] = Number((0, hex_to_decimal_1.hexToDecimal)(log[key]));
                break;
            case 'removed':
                if (receiptLog) {
                    delete cleanedLog[key];
                }
                else if (log[key] == null) {
                    cleanedLog[key] === false;
                }
                break;
        }
    });
    return cleanedLog;
}
exports.cleanLog = cleanLog;
