"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FallthroughProvider = void 0;
const logger_1 = require("../logger/logger");
const BaseProvider_1 = require("./BaseProvider");
// https://advancedweb.hu/how-to-add-timeout-to-a-promise-in-javascript/
const promiseTimeout = (prom, time) => new Promise((resolve, reject) => {
    const timeout = setTimeout(() => reject(new Error('Promise timed out')), time);
    prom
        .then((result) => {
        clearTimeout(timeout);
        resolve(result);
    })
        .catch((error) => {
        clearTimeout(timeout);
        reject(error);
    });
});
const DEFAULT_TIMEOUT_DURATION = 8000;
/**
 * @beta
 * A JSON RPC Provider which moves to the next URL when one fails.
 */
class FallthroughProvider extends BaseProvider_1.BaseProvider {
    // index of current trusted rpc url
    /**
     * @ignore
     */
    rpcUrlCounter = 0;
    timeoutDuration;
    /**
     * @ignore
     */
    selectRpcUrl() {
        return this._rpcUrls[this.rpcUrlCounter];
    }
    constructor(rpcUrls, options = {}) {
        if (!Array.isArray(rpcUrls)) {
            logger_1.logger.throwError('Array required', { rpcUrls });
        }
        if (rpcUrls.length <= 1) {
            logger_1.logger.throwError('More than one rpcUrl is required', { rpcUrls });
        }
        super(rpcUrls);
        this.timeoutDuration = options.timeoutDuration || DEFAULT_TIMEOUT_DURATION;
    }
    /**
     * @ignore
     */
    post = (body) => {
        // while failing post, add to rpcUrlCounter and post again
        const genesisCount = this.rpcUrlCounter;
        const recursivePostRetry = () => {
            // Times out request
            const genesisRpcUrl = this.selectRpcUrl();
            const res = promiseTimeout(this._post(body), this.timeoutDuration).catch((e) => {
                // A mutex: Only add if no other instance has discovered this url as failing yet
                if (genesisRpcUrl === this.selectRpcUrl()) {
                    // add one and handle array overflow
                    this.rpcUrlCounter =
                        (this.rpcUrlCounter + 1) % this._rpcUrls.length;
                }
                // we've already tried this rpc, throw for good
                if (this.rpcUrlCounter === genesisCount) {
                    throw e;
                }
                return recursivePostRetry();
            });
            return res;
        };
        return recursivePostRetry();
    };
}
exports.FallthroughProvider = FallthroughProvider;
