"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonRpcProvider = exports.JsonRpcProvider = void 0;
const BaseProvider_1 = require("./BaseProvider");
class JsonRpcProvider extends BaseProvider_1.BaseProvider {
    /**
     * @ignore
     */
    selectRpcUrl() {
        return this._rpcUrls[0];
    }
    /**
     * @ignore
     */
    post(body) {
        return this._post(body);
    }
    /**
     * @param rpcUrl The URL to your Eth node. Consider POKT or Infura
     * @example
     * `https://free-eth-node.com/api/eth`
     * @example
     * `https://mainnet.infura.io/v3/YOUR-PROJECT-ID`
     */
    constructor(rpcUrl = 'https://free-eth-node.com/api/eth') {
        super([rpcUrl]);
    }
}
exports.JsonRpcProvider = JsonRpcProvider;
/**
 * Helper function to avoid "new"
 *
 * @param rpcUrl the RPC URL to post requests to
 * @returns an initiated {@link JsonRpcProvider}
 * @example
 * ```javascript
 * jsonRpcProvider().getBlock('latest').then(block => {
 *   console.log(block.number);
 * })
 * // 14530496
 * ```
 */
function jsonRpcProvider(rpcUrl) {
    return new JsonRpcProvider(rpcUrl);
}
exports.jsonRpcProvider = jsonRpcProvider;
