"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.etherToGwei = void 0;
const tiny_big_1 = require("../shared/tiny-big/tiny-big");
const validate_type_1 = require("../shared/validate-type");
/**
 * Convert from Ether to Gwei
 *
 * No direct equivalent in ether.js; requires multiple functions to achieve.
 *
 * No direct equivalent in web3; requires multiple functions to achieve.
 *
 * @param etherQuantity the amount of ether to convert to gwei
 * @returns a number of gwei equivalent to the specified ether
 * @example
 * ```javascript
 * etherToGwei('1000').toString()
 * // '1000000000000'
 * etherToGwei(1000).toString()
 * // '1000000000000'
 * ```
 * @example
 * ```javascript
 * etherToGwei('1000').toNumber()
 * // 1000000000000
 * etherToGwei(1000).toNumber()
 * // 1000000000000
 * ```
 */
function etherToGwei(etherQuantity) {
    (0, validate_type_1.validateType)(etherQuantity, ['string', 'number', 'object']);
    const result = (0, tiny_big_1.tinyBig)(etherQuantity).times('1000000000');
    return (0, tiny_big_1.tinyBig)(result);
}
exports.etherToGwei = etherToGwei;
