"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.etherToWei = void 0;
const tiny_big_1 = require("../shared/tiny-big/tiny-big");
const validate_type_1 = require("../shared/validate-type");
/**
 * Convert Ether to Wei
 *
 * Similar to ["parseEther" in ethers.js](https://docs.ethers.io/v5/api/utils/display-logic/#utils-parseEther)
 *
 * Similar to ["toWei" in web3.js](https://web3js.readthedocs.io/en/v1.7.1/web3-utils.html#towei)
 *
 * @param etherQuantity the amount of ether to convert to wei
 * @returns a number of wei equivalent to the specified ether
 * @example
 * ```javascript
 * etherToWei('1000').toString()
 * // '1000000000000000000000'
 * etherToWei(1000).toString()
 * // '1000000000000000000000'
 * ```
 * @example
 * ```javascript
 * etherToWei('1000').toNumber()
 * // 1000000000000000000000
 * etherToWei(1000).toNumber()
 * // 1000000000000000000000
 * ```
 */
function etherToWei(etherQuantity) {
    (0, validate_type_1.validateType)(etherQuantity, ['string', 'number', 'object']);
    const result = (0, tiny_big_1.tinyBig)(etherQuantity).times('1000000000000000000');
    return (0, tiny_big_1.tinyBig)(result);
}
exports.etherToWei = etherToWei;
