"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gweiToEther = void 0;
const tiny_big_1 = require("../shared/tiny-big/tiny-big");
const validate_type_1 = require("../shared/validate-type");
/**
 * Convert from Gwei to Ether
 *
 * No direct equivalent in ethers.js; requires multiple functions to achieve.
 *
 * No direct equivalent in web3; requires multiple functions to achieve.
 *
 * @param gweiQuantity the amount of gwei to convert to ether
 * @returns a number of ether equivalent to the specified gwei
 * @example
 * ```javascript
 * gweiToEther('1000000000000').toString()
 * // '1000'
 * gweiToEther(1000000000000).toString()
 * // '1000'
 * ```
 * @example
 * ```javascript
 * gweiToEther('1000000000000').toNumber()
 * // 1000
 * gweiToEther(1000000000000).toNumber()
 * // 1000
 * ```
 */
function gweiToEther(gweiQuantity) {
    (0, validate_type_1.validateType)(gweiQuantity, ['string', 'number', 'object']);
    const result = (0, tiny_big_1.tinyBig)(gweiQuantity).div('1000000000');
    return (0, tiny_big_1.tinyBig)(result);
}
exports.gweiToEther = gweiToEther;
