"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hashMessage = void 0;
const bytes_1 = require("./bytes");
const keccak256_1 = require("./keccak256");
const to_utf8_bytes_1 = require("./to-utf8-bytes");
const messagePrefix = '\x19Ethereum Signed Message:\n';
/**
 * Computes the EIP-191 personal message digest of message.
 * Personal messages are converted to UTF-8 bytes and prefixed with \x19Ethereum Signed Message: and the length of message.
 *
 * @param message the message to hash
 * @returns a message hashed using Keccak256 that matches the EIP-191 standard
 * @example
 * ```javascript
 * hashMessage("Hello World");
 * // '0xa1de988600a42c4b4ab089b619297c17d53cffae5d5120d82d8a92d0bb3b78f2'
 * ```
 */
function hashMessage(message) {
    if (typeof message === 'string') {
        message = (0, to_utf8_bytes_1.toUtf8Bytes)(message);
    }
    return (0, keccak256_1.keccak256)((0, bytes_1.concat)([
        (0, to_utf8_bytes_1.toUtf8Bytes)(messagePrefix),
        (0, to_utf8_bytes_1.toUtf8Bytes)(String(message.length)),
        message,
    ]));
}
exports.hashMessage = hashMessage;
