"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAddress = void 0;
const validate_type_1 = require("../shared/validate-type");
const to_checksum_address_1 = require("./to-checksum-address");
/**
 * Returns a boolean as to whether the input is a valid address.
 * Does NOT support ICAP addresses
 *
 * @param address the address to check the validity of
 * @returns a boolean for whether the input is a valid address
 * @example
 * ```javascript
 * isAddress('0xc0deaf6bd3f0c6574a6a625ef2f22f62a5150eab');
 * // true
 * ```
 * @example
 * ```javascript
 * isAddress('bad');
 * // false
 * ```
 * @example
 * ```javascript
 * // Does NOT support ENS.
 * isAddress('vitalik.eth');
 * // false
 * ```
 */
function isAddress(address) {
    (0, validate_type_1.validateType)(address, ['string']);
    try {
        (0, to_checksum_address_1.toChecksumAddress)(address);
        return true;
    }
    catch (error) {
        return false;
    }
}
exports.isAddress = isAddress;
