"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.keccak256 = void 0;
const sha3_1 = require("sha3");
/**
 * Hashes data into a Keccak256 hex string
 *
 * @param data the data to be hashed using Keccak256
 * @returns a hex string with data hashed using Keccak256
 * @example
 * ```javascript
 * keccak256('essential-eth');
 * // '0xc5d2460186f7233c927e7db2dcc703c0e500b653ca82273b7bfad8045d85a470'
 *
 * keccak256('0x123');
 * // '0x5fa2358263196dbbf23d1ca7a509451f7a2f64c15837bfbb81298b1e3e24e4fa'
 * ```
 */
function keccak256(data) {
    let bufferableData;
    if (typeof data === 'string') {
        bufferableData = Buffer.from(data.replace(/^0x/, ''), 'hex');
    }
    else {
        bufferableData = Buffer.from(data);
    }
    const keccak = new sha3_1.Keccak(256);
    const addressHash = '0x' + keccak.update(bufferableData).digest('hex');
    return addressHash;
}
exports.keccak256 = keccak256;
