import type Big from 'big.js';
import type { TinyBig } from '../shared/tiny-big/tiny-big';
/**
 * Convert from Wei to Ether
 *
 * Similar to ["formatEther" in ethers.js](https://docs.ethers.io/v5/api/utils/display-logic/#utils-formatEther)
 *
 * Similar to ["fromWei" in web3.js](https://web3js.readthedocs.io/en/v1.7.1/web3-utils.html#fromwei)
 *
 * @param weiQuantity the amount of wei to convert to ether
 * @returns a number of ether equivalent to the specified wei
 * @example
 * ```javascript
 * weiToEther('1000000000000000000000').toString()
 * // '1000'
 * weiToEther(1000000000000000000000).toString()
 * // '1000'
 * ```
 * @example
 * ```javascript
 * weiToEther('1000000000000000000000').toNumber()
 * // 1000
 * weiToEther(1000000000000000000000).toNumber()
 * // 1000
 * ```
 */
export declare function weiToEther(weiQuantity: string | number | TinyBig | Big): TinyBig;
