import { decodeRPCResponse, encodeData, } from './utils/encode-decode-transaction';
function estimateGas(txnData) {
    txnData.split('').reduce((previousValue, currentValue) => {
        const characterCost = currentValue === '0' ? 4 : 68;
        return previousValue + characterCost;
    }, 0);
}
export class BaseContract {
    _address;
    _provider;
    constructor(addressOrName, contractInterface, signerOrProvider) {
        this._address = addressOrName;
        this._provider = signerOrProvider;
        contractInterface
            .filter((jsonABIArgument) => jsonABIArgument.type === 'function')
            .forEach((jsonABIArgument) => {
            if ('name' in jsonABIArgument &&
                typeof jsonABIArgument.name === 'string') {
                defineReadOnly(this, jsonABIArgument.name, async (..._args) => {
                    let functionArguments = _args;
                    let options = {};
                    const lastArg = _args[_args.length - 1];
                    if (!Array.isArray(lastArg) && typeof lastArg === 'object') {
                        options = lastArg;
                        functionArguments = _args.slice(0, _args.length - 1);
                    }
                    const data = encodeData(jsonABIArgument, functionArguments);
                    const decimalGas = typeof options.gasLimit === 'number'
                        ? options.gasLimit
                        : typeof jsonABIArgument?.gas ===
                            'number'
                            ? estimateGas(data)
                            : null;
                    const req = async () => {
                        return await this._provider.call({
                            to: this._address.toLowerCase(),
                            data,
                            ...(decimalGas
                                ? { gas: `0x${decimalGas.toString(16)}` }
                                : {}),
                        }, 'latest');
                    };
                    const nodeResponse = await req();
                    return decodeRPCResponse(jsonABIArgument, nodeResponse);
                });
            }
        });
    }
}
export function defineReadOnly(object, name, value) {
    Object.defineProperty(object, name, {
        enumerable: true,
        value: value,
        writable: false,
    });
}
export class Contract extends BaseContract {
}
