import { logger } from '../logger/logger';
import { BaseProvider } from './BaseProvider';
const promiseTimeout = (prom, time) => new Promise((resolve, reject) => {
    const timeout = setTimeout(() => reject(new Error('Promise timed out')), time);
    prom
        .then((result) => {
        clearTimeout(timeout);
        resolve(result);
    })
        .catch((error) => {
        clearTimeout(timeout);
        reject(error);
    });
});
const DEFAULT_TIMEOUT_DURATION = 8000;
export class FallthroughProvider extends BaseProvider {
    rpcUrlCounter = 0;
    timeoutDuration;
    selectRpcUrl() {
        return this._rpcUrls[this.rpcUrlCounter];
    }
    constructor(rpcUrls, options = {}) {
        if (!Array.isArray(rpcUrls)) {
            logger.throwError('Array required', { rpcUrls });
        }
        if (rpcUrls.length <= 1) {
            logger.throwError('More than one rpcUrl is required', { rpcUrls });
        }
        super(rpcUrls);
        this.timeoutDuration = options.timeoutDuration || DEFAULT_TIMEOUT_DURATION;
    }
    post = (body) => {
        const genesisCount = this.rpcUrlCounter;
        const recursivePostRetry = () => {
            const genesisRpcUrl = this.selectRpcUrl();
            const res = promiseTimeout(this._post(body), this.timeoutDuration).catch((e) => {
                if (genesisRpcUrl === this.selectRpcUrl()) {
                    this.rpcUrlCounter =
                        (this.rpcUrlCounter + 1) % this._rpcUrls.length;
                }
                if (this.rpcUrlCounter === genesisCount) {
                    throw e;
                }
                return recursivePostRetry();
            });
            return res;
        };
        return recursivePostRetry();
    };
}
